stravalib.util.limiter.RateLimiter
==================================

.. currentmodule:: stravalib.util.limiter

.. autoclass:: RateLimiter


   .. automethod:: __init__


   .. rubric:: Methods

   .. autosummary::

      ~RateLimiter.__init__
